@@ -3,6 +3,8 @@ package Geo::Parser::Text;
 use 5.006;
 use strict;
 use warnings;
+use utf8::all;
+use open ':utf8';
 
 use XML::Simple;
 use LWP::UserAgent;
@@ -89,16 +91,16 @@ warn $result if DEBUG;
 
 =head1 NAME
 
-Geo::Parser::Text - Perl extension for parsing, geocoding and standardizing locations from free form text. Worldwide Coverage. Geocode places to latitude, longitude, elevation.
+Geo::Parser::Text - Perl extension for geoparsing, geocoding and standardizing locations from free form text. Worldwide Coverage. Geocode places to latitude, longitude, elevation.
 And vice-versa.
 
 =head1 VERSION
 
-Version 0.05
+Version 0.051
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.051';
 
 
 =head1 SYNOPSIS
@@ -161,7 +163,7 @@ our $VERSION = '0.05';
 
 	#forward geocode and cleanup/standardize input address
 
-	my $ref = $g->geocode(locate=>'10 Downing St, londino UK');                    
+	my $ref = $g->geocode(locate=>'10 Downing St, Londino UK');                    
   	print Dumper $ref;
 
 	#expected response
